@@ -1,14 +1,13 @@
 #
 #  Spreadsheet::BasicRead.pm
 #
-#  Synopsis:            see POD at end of file
-#
+#  Synopsis: see POD at end of file
 #
 #-- The package
 #--------------------------------------------------
 package Spreadsheet::BasicRead;
 
-$VERSION = sprintf("%d.%02d", q'$Revision: 1.11 $' =~ /(\d+)\.(\d+)/);
+$VERSION = '1.12';
 #--------------------------------------------------
 #
 
@@ -92,9 +91,10 @@ sub openSpreadsheet
     #-- Open the Excel spreadsheet and process
     my $ssExcel;
     my $ssBook;
-    if ($ssFileName =~ /\.xlsx$/i)
+    if ($ssFileName =~ /\.xls[xm]$/i)
     {
-        $ssExcel = Spreadsheet::XLSX->new($ssFileName);
+        my $converter = Spreadsheet::XLSX::XLSXConvert->new();
+        $ssExcel = Spreadsheet::XLSX->new($ssFileName, $converter);
         $ssBook  = $ssExcel;
     }
     else
@@ -350,7 +350,24 @@ sub logmsg
     }
 }
 
+{
+    package Spreadsheet::XLSX::XLSXConvert;
+    sub new {
+        my $module = shift;
 
+        return bless( {  }, $module );
+    }
+    sub convert {
+        my $self = shift;
+        my ($raw) = @_;
+        utf8::decode($raw);
+        #also decode html escapes,
+        $raw =~ s/\&amp;/&/g;
+        $raw =~ s/\&lt;/\</g;
+        $raw =~ s/\&gt;/\>/g;
+        return $raw;
+    }
+}
 
 #####################################################################
 # DO NOT REMOVE THE FOLLOWING LINE, IT IS NEEDED TO LOAD THIS LIBRARY
@@ -363,7 +380,7 @@ __END__
 
 =head1 NAME
 
-Spreadsheet::BasicRead - Methods to easily read data from spreadsheets (.xls and .xlxs)
+Spreadsheet::BasicRead - Methods to easily read data from spreadsheets (.xls, .xlxs and .xlxm)
 
 
 =head1 DESCRIPTION
@@ -380,7 +397,7 @@ Properties can also be set to skip the heading row.
  Note 2. Row and column references are zero (0) indexed. That is cell
          A1 is row 0, column 0
 
- Note 3. Now handles .xlxs files
+ Note 3. Now handles .xlxs and .xlsm files
 
 =head1 SYNOPSIS
 
@@ -484,7 +501,7 @@ The old functionality can be turned on by setting argument I<oldCell> to true
 =back
 
 B<Note that new will die if the spreadsheet can not be successfully opened.>
-As such you may wish to wrap the call to new in a eval block. See L<xlsgrep|EXAMPLE APPLICATIONS>
+As such you may wish to wrap the call to new in a eval block. See xlsgrep|EXAMPLE APPLICATIONS
 for an example of when this might be desirable.
 
 =head2 getNextRow()
@@ -654,14 +671,17 @@ program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 
-=head1 CVS ID
+=head1 VERSION
 
-$Id: BasicRead.pm,v 1.11 2012/04/10 11:08:42 Greg Exp $
+This is version 1.12
 
 
 =head1 UPDATE HISTORY
 
- $Log: BasicRead.pm,v $
+ Revision 1.12  2017/05/01 Greg
+ - Added handling of .xlxs & .xlxm files
+ - Added utf8 conversion for .xls[x|m] files as well as decoding of html escapes &amp; &lt; and &gt;
+
  Revision 1.11  2012/04/10 11:08:42  Greg
  - Added handling of .xlxs files
 
@@ -702,7 +722,6 @@ $Id: BasicRead.pm,v 1.11 2012/04/10 11:08:42 Greg Exp $
  Revision 1.1.1.1  2004/07/31 07:45:02  Greg
  - Initial release to CPAN
 
-
 =cut
 
 #---< End of File >---#
\ No newline at end of file
