@@ -6,7 +6,7 @@
 # change 'tests => 1' to 'tests => last_test_to_print';
 
 use Test;
-BEGIN { plan tests => 5 };
+BEGIN { plan tests => 6 };
 use Spreadsheet::BasicRead;
 print 'Use it...........................';
 ok(1); # If we made it this far, we're ok.
@@ -38,4 +38,24 @@ my $cnt = $ss->numSheets();
 print "Getting number sheets ($cnt)........";
 ok( $cnt, 3 );
 
+## Test we can read all the data
+print "Dumping the entire spreadsheet:\n";
+print " Expecting Sht1: 3 row x 3 col, Sht2: 2 row x 3 col, Sht 3: 1 row x 3 col:\n";
+my $rows = 0;
+$ss->getFirstSheet();
+do
+{
+	print '  *** ', $ss->currentSheetName(), " ***\n";
+
+	# Print the row number and data for each row of the
+	# spreadsheet to stdout using '|' as a separator
+	while (my $data = $ss->getNextRow())
+	{
+		no warnings qw(uninitialized);
+		$rows++;
+		print '  ', join('|', $row, @$data), "\n";
+	}
+} while ($ss->getNextSheet());
+ok( $rows, 6 );
+
 #---<end of File >---#
\ No newline at end of file
